Internationalization and localization tools.


Install
-------

    pip install g11npy

You can also download/clone the source, in which case you have to:

    git clone https://github.com/TNick/g11n.git
    python setup.py install
        
To contribute a patch clone the repo, create a new branch, install in
develop mode:
        
    python setup.py develop
